@@ -6,6 +6,12 @@ from pydantic import BaseModel as _BaseModel, ConfigDict as _ConfigDict, Field a
 
 # MODELS
 from alphaz_next.models.config.apm_config import ApmConfig as _ApmConfig
+from alphaz_next.models.config.database_config import (
+    DatabasesConfigSchema as _DatabasesConfigSchema,
+)
+from alphaz_next.models.config.directories_config import (
+    DirectoriesSchema as _DirectoriesSchema,
+)
 from alphaz_next.models.config.logging_config import LoggingSchema as _LoggingSchema
 from alphaz_next.models.config.openapi_config_schema import (
     OpenApiSchema as _OpenApiSchema,
@@ -22,7 +28,8 @@ class AlphaApiConfigSchema(_BaseModel):
         extra="allow",
     )
 
-    databases_config_path: str
-    logging: _LoggingSchema
+    databases_config: _DatabasesConfigSchema
+    directories: _DirectoriesSchema
+    logging: _Optional[_LoggingSchema] = _Field(default=None)
     apm: _Optional[_ApmConfig] = _Field(default=None)
     openapi: _Optional[_OpenApiSchema] = _Field(default=None)
